==> lueur-0.1.0.tar.gz: lueur-0.1.0/lueur/platform/gcp/securities.py <==
# mypy: disable-error-code="union-attr"
import msgspec

from lueur.make_id import make_id
from lueur.models import GCPMeta, Resource
from lueur.platform.gcp.client import AuthorizedSession, Client

__all__ = ["explore_securities"]


async def explore_securities(
    project: str, location: str | None = None
) -> list[Resource]:
    resources = []

    async with Client("https://compute.googleapis.com") as c:
        if not location:
            securities = await explore_global_securities(c, project)
            resources.extend(securities)
        else:
            securities = await explore_regional_securities(c, project, location)
            resources.extend(securities)

    return resources


###############################################################################
# Private functions
###############################################################################
async def explore_global_securities(
    c: AuthorizedSession, project: str
) -> list[Resource]:
    response = await c.get(
        f"/compute/v1/projects/{project}/global/securityPolicies"
    )

    securities = msgspec.json.decode(response.content)

    results = []
    for security in securities.get("items", []):
        self_link = security["selfLink"]
        name = security["name"]
        display = name

        results.append(
            Resource(
                id=make_id(security["id"]),
                meta=GCPMeta(
                    name=name,
                    display=display,
                    kind="global-securities",
                    project=project,
                    self_link=self_link,
                ),
                struct=security,
            )
        )

    return results


async def explore_regional_securities(
    c: AuthorizedSession, project: str, location: str
) -> list[Resource]:
    response = await c.get(
        f"/compute/v1/projects/{project}/regions/{location}/securityPolicies"
    )

    securities = msgspec.json.decode(response.content)

    results = []
    for security in securities.get("items", []):
        self_link = security["selfLink"]
        name = security["name"]
        display = name

        results.append(
            Resource(
                id=make_id(security["id"]),
                meta=GCPMeta(
                    name=name,
                    display=display,
                    kind="regional-securities",
                    project=project,
                    self_link=self_link,
                    region=location,
                ),
                struct=security,
            )
        )

    return results

==> lueur-0.3.0.tar.gz: lueur-0.3.0/lueur/platform/gcp/securities.py <==
# mypy: disable-error-code="union-attr"
import msgspec
from google.oauth2._service_account_async import Credentials

from lueur.make_id import make_id
from lueur.models import GCPMeta, Resource
from lueur.platform.gcp.client import AuthorizedSession, Client

__all__ = ["explore_securities"]


async def explore_securities(
    project: str, location: str | None = None, creds: Credentials | None = None
) -> list[Resource]:
    resources = []

    async with Client("https://compute.googleapis.com", creds) as c:
        if not location:
            securities = await explore_global_securities(c, project)
            resources.extend(securities)
        else:
            securities = await explore_regional_securities(c, project, location)
            resources.extend(securities)

    return resources


###############################################################################
# Private functions
###############################################################################
async def explore_global_securities(
    c: AuthorizedSession, project: str
) -> list[Resource]:
    response = await c.get(
        f"/compute/v1/projects/{project}/global/securityPolicies"
    )

    securities = msgspec.json.decode(response.content)

    results = []
    for security in securities.get("items", []):
        self_link = security["selfLink"]
        name = security["name"]
        display = name

        results.append(
            Resource(
                id=make_id(security["id"]),
                meta=GCPMeta(
                    name=name,
                    display=display,
                    kind="global-securities",
                    project=project,
                    self_link=self_link,
                ),
                struct=security,
            )
        )

    return results


async def explore_regional_securities(
    c: AuthorizedSession, project: str, location: str
) -> list[Resource]:
    response = await c.get(
        f"/compute/v1/projects/{project}/regions/{location}/securityPolicies"
    )

    securities = msgspec.json.decode(response.content)

    results = []
    for security in securities.get("items", []):
        self_link = security["selfLink"]
        name = security["name"]
        display = name

        results.append(
            Resource(
                id=make_id(security["id"]),
                meta=GCPMeta(
                    name=name,
                    display=display,
                    kind="regional-securities",
                    project=project,
                    self_link=self_link,
                    region=location,
                ),
                struct=security,
            )
        )

    return results
